@@ -21,4 +21,8 @@ EXTRA_DATA_FILE_EXTENSIONS = ('.extra.json', '.extra_data.json', '.extra_data.h5
 FRAME_MD = ('frame_number', 'frame_time')
 VERBOSE_DEBUG_CHUNKS=False
 CONFIG_FILE=os.path.join(os.environ["HOME"], ".config", "imgstore", "imgstore.yml")
-SQLITE3_INDEX_FILE="index.db"
\ No newline at end of file
+SQLITE3_INDEX_FILE="index.db"
+FRAME_NUMBER_RESET=True
+MULTI_STORE_ENABLED=False
+COLOR=True
+SELECTED_STORE="lowres/metadata.yaml"
\ No newline at end of file
