@@ -8,7 +8,7 @@ import warnings
 import yaml
 import numpy as np
 
-from .constants import FRAME_MD, SQLITE3_INDEX_FILE
+from .constants import FRAME_MD, SQLITE3_INDEX_FILE, FRAME_NUMBER_RESET
 
 
 def _load_index(path_without_extension):
@@ -90,6 +90,9 @@ class ImgStoreIndex(object):
             for chunk_n, chunk_path in sorted(chunk_n_and_chunk_paths, key=operator.itemgetter(0)):
                 try:
                     idx = _load_index(chunk_path)
+                    if FRAME_NUMBER_RESET:
+                        idx["frame_number"] = list(range(frame_count, frame_count+len(idx["frame_number"])))
+
                 except IOError:
                     cls.log.warn('missing index for chunk %s' % chunk_n)
                     continue
@@ -279,20 +282,57 @@ class ImgStoreIndex(object):
 
         return chunk_n, frame_idx
 
-    def find_chunk_nearest(self, what, value):
+    def find_chunk_nearest(self, what, value, past=True, future=True):
+        # future: frame_time >= value
+        # past: frame_time <= value
+
         assert what in ('frame_number', 'frame_time')
         cur = self._conn.cursor()
-        cur.execute("SELECT chunk, frame_idx FROM frames ORDER BY ABS(? - {}) LIMIT 1;".format(what), (value, ))
+
+        if what=="frame_time":
+            cur.execute("SELECT frame_time from frames LIMIT 1;")
+            ft=cur.fetchone()[0]
+            if type(ft) is float:
+                value=float(value)
+
+        if past and future:
+            cur.execute("SELECT chunk, frame_idx FROM frames ORDER BY ABS(? - {}) LIMIT 1;".format(what), (value, ))
+        elif not future:
+            # we want only frame_time <= value
+            # frame_time - value will be max 0
+            cur.execute("SELECT chunk, frame_idx FROM frames WHERE ({} - ?) <= 0 ORDER BY ABS(? - {}) LIMIT 1;".format(what, what), (value, value))
+        elif not past:
+            # we want only frame_time >= value
+            # frame_time - value will be min 0
+            cur.execute("SELECT chunk, frame_idx FROM frames WHERE ({} - ?) >= 0 ORDER BY ABS(? - {}) LIMIT 1;".format(what, what), (value, value))
+
         chunk_n, frame_idx = cur.fetchone()
         return chunk_n, frame_idx
 
-    def find_all(self, what, value, exact_only=True):
+    def find_all(self, what, value, exact_only=True, past=True, future=True):
         assert what in ('frame_number', 'frame_time')
         cur = self._conn.cursor()
+        
         if exact_only:
-            cur.execute("SELECT * FROM frames WHERE {} = ?;".format(what), (value, ))
-        else:
-            cur.execute("SELECT * FROM frames ORDER BY ABS(? - {}) LIMIT 1;".format(what), (value, ))
+            filter= f"WHERE {what} = ?"
+            val_tuple = (value,)
+
+        elif past and future:
+            filter=f" ORDER BY ABS(? - {what}) LIMIT 1"
+            val_tuple = (value,)
+
+        elif not future:
+            filter=f"WHERE ({what} - ?) <= 0 ORDER BY ABS(? - {what}) LIMIT 1"
+            val_tuple = (value, value,)
+
+        elif not past:
+            filter=f"WHERE ({what} - ?) >= 0 ORDER BY ABS(? - {what}) LIMIT 1"
+            val_tuple = (value, value,)
+
+
+        cmd=f"SELECT * FROM frames {filter};"
+        cur.execute(cmd, val_tuple)
+
         data = cur.fetchone()
         if data is None:
 
@@ -304,4 +344,4 @@ class ImgStoreIndex(object):
             for w in _what:
                 error_msg+=f"{w}={str(self._summary(w))} "
             raise Exception(error_msg)
-        return data
\ No newline at end of file
+        return data
